@@ -33,15 +33,14 @@ build_time_vars = {'ABIFLAGS': '',
            '-I/src/build_linux/deps/Release/zlib/include -fPIC -fPIC',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-I/src/build_linux/deps/Release/sqlite/include '
                      '-I/src/build_linux/deps/Release/bzip2/include '
                      '-I/src/build_linux/deps/Release/lzma/include '
                      '-I/src/build_linux/deps/Release/zlib/include -fPIC',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-fno-semantic-interposition -std=c99 -Wextra '
+                            '-Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
@@ -54,9 +53,9 @@ build_time_vars = {'ABIFLAGS': '',
                       '-L/src/build_linux/deps/Release/bzip2/lib '
                       '-L/src/build_linux/deps/Release/lzma/lib '
                       '-L/src/build_linux/deps/Release/zlib/lib',
- 'CONFIGURE_LDFLAGS_NODIST': '',
+ 'CONFIGURE_LDFLAGS_NODIST': '-fno-semantic-interposition',
  'CONFIG_ARGS': "'--prefix=/src/build_linux/deps/Release/python' "
-                "'--with-openssl=/src/build_linux/deps/Release/ssl' "
+                "'--enable-optimizations' "
                 "'CFLAGS=-I/src/build_linux/deps/Release/sqlite/include "
                 '-I/src/build_linux/deps/Release/bzip2/include '
                 '-I/src/build_linux/deps/Release/lzma/include '
@@ -70,7 +69,7 @@ build_time_vars = {'ABIFLAGS': '',
                 '-I/src/build_linux/deps/Release/bzip2/include '
                 '-I/src/build_linux/deps/Release/lzma/include '
                 "-I/src/build_linux/deps/Release/zlib/include -fPIC' "
-                "'PKG_CONFIG_PATH=/src/build_linux/deps/Release/ffi/lib/pkgconfig'",
+                "'PKG_CONFIG_PATH=/src/build_linux/deps/Release/ffi/lib/pkgconfig:/src/build_linux/deps/Release/ssl/lib/pkgconfig:/src/build_linux/deps/Release/ssl/lib64/pkgconfig'",
  'CONFINCLUDEDIR': '/src/build_linux/deps/Release/python/include',
  'CONFINCLUDEPY': '/src/build_linux/deps/Release/python/include/python3.10',
  'COREPYTHONPATH': '',
@@ -159,7 +158,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
- 'HAVE_COPY_FILE_RANGE': 0,
+ 'HAVE_COPY_FILE_RANGE': 1,
  'HAVE_CRYPT_H': 1,
  'HAVE_CRYPT_R': 1,
  'HAVE_CTERMID': 1,
@@ -209,7 +208,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERRNO_H': 1,
  'HAVE_EVENTFD': 1,
  'HAVE_EXECV': 1,
- 'HAVE_EXPLICIT_BZERO': 0,
+ 'HAVE_EXPLICIT_BZERO': 1,
  'HAVE_EXPLICIT_MEMSET': 0,
  'HAVE_EXPM1': 1,
  'HAVE_FACCESSAT': 1,
@@ -248,7 +247,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
- 'HAVE_GETENTROPY': 0,
+ 'HAVE_GETENTROPY': 1,
  'HAVE_GETGRGID_R': 1,
  'HAVE_GETGRNAM_R': 1,
  'HAVE_GETGROUPLIST': 1,
@@ -271,7 +270,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETPWENT': 1,
  'HAVE_GETPWNAM_R': 1,
  'HAVE_GETPWUID_R': 1,
- 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM': 1,
  'HAVE_GETRANDOM_SYSCALL': 1,
  'HAVE_GETRESGID': 1,
  'HAVE_GETRESUID': 1,
@@ -321,7 +320,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
- 'HAVE_LINUX_QRTR_H': 0,
+ 'HAVE_LINUX_QRTR_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 1,
@@ -335,7 +334,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MADVISE': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMFD_CREATE': 0,
+ 'HAVE_MEMFD_CREATE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -366,7 +365,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_POSIX_SPAWNP': 1,
  'HAVE_PREAD': 1,
  'HAVE_PREADV': 1,
- 'HAVE_PREADV2': 0,
+ 'HAVE_PREADV2': 1,
  'HAVE_PRLIMIT': 1,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
@@ -380,7 +379,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTY_H': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
- 'HAVE_PWRITEV2': 0,
+ 'HAVE_PWRITEV2': 1,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -495,7 +494,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
- 'HAVE_SYS_RANDOM_H': 0,
+ 'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 1,
@@ -577,7 +576,6 @@ build_time_vars = {'ABIFLAGS': '',
             '-L/src/build_linux/deps/Release/bzip2/lib '
             '-L/src/build_linux/deps/Release/lzma/lib '
             '-L/src/build_linux/deps/Release/zlib/lib',
- 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.10.a',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -pthread -shared -L/src/build_linux/deps/Release/ffi/lib '
@@ -617,7 +615,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 0,
+ 'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/src/build_linux/deps/Release/python/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
@@ -646,7 +644,7 @@ build_time_vars = {'ABIFLAGS': '',
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
  'OPENSSL_INCLUDES': '-I/src/build_linux/deps/Release/ssl/include',
- 'OPENSSL_LDFLAGS': '-L/src/build_linux/deps/Release/ssl/lib',
+ 'OPENSSL_LDFLAGS': '-L/src/build_linux/deps/Release/ssl/lib64',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
@@ -689,11 +687,12 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I/src/build_linux/deps/Release/bzip2/include '
                              '-I/src/build_linux/deps/Release/lzma/include '
                              '-I/src/build_linux/deps/Release/zlib/include '
-                             '-fPIC -fPIC -std=c99 -Wextra -Wno-unused-result '
-                             '-Wno-unused-parameter '
+                             '-fPIC -fPIC -fno-semantic-interposition -std=c99 '
+                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-fvisibility=hidden -fprofile-use '
+                             '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include '
                              '-I/src/build_linux/deps/Release/sqlite/include '
                              '-I/src/build_linux/deps/Release/bzip2/include '
@@ -705,20 +704,24 @@ build_time_vars = {'ABIFLAGS': '',
               '-I/src/build_linux/deps/Release/bzip2/include '
               '-I/src/build_linux/deps/Release/lzma/include '
               '-I/src/build_linux/deps/Release/zlib/include -fPIC -fPIC',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+ 'PY_CFLAGS_NODIST': '-fno-semantic-interposition -std=c99 -Wextra '
+                     '-Wno-unused-result -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  -I./Include/internal',
+                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -I/src/build_linux/deps/Release/sqlite/include '
                    '-I/src/build_linux/deps/Release/bzip2/include '
                    '-I/src/build_linux/deps/Release/lzma/include '
                    '-I/src/build_linux/deps/Release/zlib/include -fPIC -fPIC '
-                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-fno-semantic-interposition -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
+                   '-fprofile-use -fprofile-correction -I./Include/internal '
+                   '-I. -I./Include '
                    '-I/src/build_linux/deps/Release/sqlite/include '
                    '-I/src/build_linux/deps/Release/bzip2/include '
                    '-I/src/build_linux/deps/Release/lzma/include '
@@ -728,7 +731,8 @@ build_time_vars = {'ABIFLAGS': '',
                     '-L/src/build_linux/deps/Release/sqlite/lib '
                     '-L/src/build_linux/deps/Release/bzip2/lib '
                     '-L/src/build_linux/deps/Release/lzma/lib '
-                    '-L/src/build_linux/deps/Release/zlib/lib',
+                    '-L/src/build_linux/deps/Release/zlib/lib '
+                    '-fno-semantic-interposition',
  'PY_CPPFLAGS': '-I. -I./Include '
                 '-I/src/build_linux/deps/Release/sqlite/include '
                 '-I/src/build_linux/deps/Release/bzip2/include '
@@ -741,7 +745,7 @@ build_time_vars = {'ABIFLAGS': '',
                '-L/src/build_linux/deps/Release/bzip2/lib '
                '-L/src/build_linux/deps/Release/lzma/lib '
                '-L/src/build_linux/deps/Release/zlib/lib',
- 'PY_LDFLAGS_NODIST': '',
+ 'PY_LDFLAGS_NODIST': '-fno-semantic-interposition',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
@@ -750,10 +754,12 @@ build_time_vars = {'ABIFLAGS': '',
                         '-I/src/build_linux/deps/Release/bzip2/include '
                         '-I/src/build_linux/deps/Release/lzma/include '
                         '-I/src/build_linux/deps/Release/zlib/include -fPIC '
-                        '-fPIC -std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-fPIC -fno-semantic-interposition -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-fvisibility=hidden -fprofile-use '
+                        '-fprofile-correction -I./Include/internal -I. '
                         '-I./Include '
                         '-I/src/build_linux/deps/Release/sqlite/include '
                         '-I/src/build_linux/deps/Release/bzip2/include '
