@@ -1,22 +1,4 @@
-# ##### BEGIN GPL LICENSE BLOCK #####
-#
-#  This program is free software; you can redistribute it and/or
-#  modify it under the terms of the GNU General Public License
-#  as published by the Free Software Foundation; either version 2
-#  of the License, or (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software Foundation,
-#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-#
-# ##### END GPL LICENSE BLOCK #####
-
-# <pep8 compliant>
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 import bpy
 
@@ -26,6 +8,8 @@ from bpy_extras import (
     asset_utils,
 )
 
+from bpy.app.translations import contexts as i18n_contexts
+
 
 class FILEBROWSER_HT_header(Header):
     bl_space_type = 'FILE_BROWSER'
@@ -38,7 +22,7 @@ class FILEBROWSER_HT_header(Header):
 
         layout.separator_spacer()
 
-        if params.asset_library_ref != 'LOCAL':
+        if params.asset_library_ref not in {'LOCAL', 'ESSENTIALS'}:
             layout.prop(params, "import_type", text="")
 
         layout.separator_spacer()
@@ -59,14 +43,14 @@ class FILEBROWSER_HT_header(Header):
         layout.popover(
             panel="ASSETBROWSER_PT_filter",
             text="",
-            icon='FILTER'
+            icon='FILTER',
         )
 
         layout.operator(
             "screen.region_toggle",
             text="",
             icon='PREFERENCES',
-            depress=is_option_region_visible(context, space_data)
+            depress=is_option_region_visible(context, space_data),
         ).region_type = 'TOOL_PROPS'
 
     def draw(self, context):
@@ -247,6 +231,7 @@ class FILEBROWSER_PT_bookmarks_volumes(Panel):
     bl_region_type = 'TOOLS'
     bl_category = "Bookmarks"
     bl_label = "Volumes"
+    bl_translation_context = i18n_contexts.editor_filebrowser
 
     @classmethod
     def poll(cls, context):
@@ -482,7 +467,7 @@ class FILEBROWSER_PT_directory_path(Panel):
                 "screen.region_toggle",
                 text="",
                 icon='PREFERENCES',
-                depress=is_option_region_visible(context, space)
+                depress=is_option_region_visible(context, space),
             ).region_type = 'TOOL_PROPS'
 
 
@@ -553,6 +538,7 @@ class FILEBROWSER_MT_context_menu(FileBrowserMenu, Menu):
         layout.operator("file.next", text="Forward")
         layout.operator("file.parent", text="Go to Parent")
         layout.operator("file.refresh", text="Refresh")
+        layout.menu("FILEBROWSER_MT_operations_menu")
 
         layout.separator()
 
@@ -584,6 +570,21 @@ class FILEBROWSER_MT_context_menu(FileBrowserMenu, Menu):
         layout.prop_menu_enum(params, "sort_method")
 
 
+class FILEBROWSER_MT_view_pie(Menu):
+    bl_label = "View"
+    bl_idname = "FILEBROWSER_MT_view_pie"
+
+    def draw(self, context):
+        layout = self.layout
+
+        pie = layout.menu_pie()
+        view = context.space_data
+
+        pie.prop_enum(view.params, "display_type", value='LIST_VERTICAL')
+        pie.prop_enum(view.params, "display_type", value='LIST_HORIZONTAL')
+        pie.prop_enum(view.params, "display_type", value='THUMBNAIL')
+
+
 class ASSETBROWSER_PT_display(asset_utils.AssetBrowserPanel, Panel):
     bl_region_type = 'HEADER'
     bl_label = "Display Settings"  # Shows as tooltip in popover
@@ -647,7 +648,7 @@ class ASSETBROWSER_MT_editor_menus(AssetBrowserMenu, Menu):
 
         layout.menu("ASSETBROWSER_MT_view")
         layout.menu("ASSETBROWSER_MT_select")
-        layout.menu("ASSETBROWSER_MT_edit")
+        layout.menu("ASSETBROWSER_MT_catalog")
 
 
 class ASSETBROWSER_MT_view(AssetBrowserMenu, Menu):
@@ -686,8 +687,8 @@ class ASSETBROWSER_MT_select(AssetBrowserMenu, Menu):
         layout.operator("file.select_box")
 
 
-class ASSETBROWSER_MT_edit(AssetBrowserMenu, Menu):
-    bl_label = "Edit"
+class ASSETBROWSER_MT_catalog(AssetBrowserMenu, Menu):
+    bl_label = "Catalog"
 
     def draw(self, _context):
         layout = self.layout
@@ -695,12 +696,25 @@ class ASSETBROWSER_MT_edit(AssetBrowserMenu, Menu):
         layout.operator("asset.catalog_undo", text="Undo")
         layout.operator("asset.catalog_redo", text="Redo")
 
+        layout.separator()
+        layout.operator("asset.catalogs_save")
+        layout.operator("asset.catalog_new").parent_path = ""
+
 
 class ASSETBROWSER_PT_metadata(asset_utils.AssetBrowserPanel, Panel):
     bl_region_type = 'TOOL_PROPS'
     bl_label = "Asset Metadata"
     bl_options = {'HIDE_HEADER'}
 
+    @staticmethod
+    def metadata_prop(layout, asset_data, propname):
+        """
+        Only display properties that are either set or can be modified (i.e. the
+        asset is in the current file). Empty, non-editable fields are not really useful.
+        """
+        if getattr(asset_data, propname) or not asset_data.is_property_readonly(propname):
+            layout.prop(asset_data, propname)
+
     def draw(self, context):
         layout = self.layout
         wm = context.window_manager
@@ -710,16 +724,14 @@ class ASSETBROWSER_PT_metadata(asset_utils.AssetBrowserPanel, Panel):
             layout.label(text="No active asset", icon='INFO')
             return
 
-        asset_library_ref = context.asset_library_ref
-        asset_lib_path = bpy.types.AssetHandle.get_full_library_path(asset_file_handle, asset_library_ref)
-
         prefs = context.preferences
         show_asset_debug_info = prefs.view.show_developer_ui and prefs.experimental.show_asset_debug_info
+        is_local_asset = bool(asset_file_handle.local_id)
 
         layout.use_property_split = True
         layout.use_property_decorate = False  # No animation.
 
-        if asset_file_handle.local_id:
+        if is_local_asset:
             # If the active file is an ID, use its name directly so renaming is possible from right here.
             layout.prop(asset_file_handle.local_id, "name")
 
@@ -739,11 +751,14 @@ class ASSETBROWSER_PT_metadata(asset_utils.AssetBrowserPanel, Panel):
                 col.prop(asset_file_handle.asset_data, "catalog_simple_name", text="Simple Name")
 
         row = layout.row(align=True)
-        row.prop(wm, "asset_path_dummy", text="Source")
+        row.prop(wm, "asset_path_dummy", text="Source", icon='CURRENT_FILE' if is_local_asset else 'NONE')
         row.operator("asset.open_containing_blend_file", text="", icon='TOOL_SETTINGS')
 
-        layout.prop(asset_file_handle.asset_data, "description")
-        layout.prop(asset_file_handle.asset_data, "author")
+        asset_data = asset_file_handle.asset_data
+        self.metadata_prop(layout, asset_data, "description")
+        self.metadata_prop(layout, asset_data, "license")
+        self.metadata_prop(layout, asset_data, "copyright")
+        self.metadata_prop(layout, asset_data, "author")
 
 
 class ASSETBROWSER_PT_metadata_preview(asset_utils.AssetMetaDataPanel, Panel):
@@ -767,7 +782,7 @@ class ASSETBROWSER_PT_metadata_preview(asset_utils.AssetMetaDataPanel, Panel):
 class ASSETBROWSER_MT_metadata_preview_menu(bpy.types.Menu):
     bl_label = "Preview"
 
-    def draw(self, context):
+    def draw(self, _context):
         layout = self.layout
         layout.operator("ed.lib_id_generate_preview_from_object", text="Render Active Object")
 
@@ -795,7 +810,7 @@ class ASSETBROWSER_UL_metadata_tags(UIList):
         row = layout.row(align=True)
         # Non-editable entries would show grayed-out, which is bad in this specific case, so switch to mere label.
         if tag.is_property_readonly("name"):
-            row.label(text=tag.name, icon_value=icon)
+            row.label(text=tag.name, icon_value=icon, translate=False)
         else:
             row.prop(tag, "name", text="", emboss=False, icon_value=icon)
 
@@ -843,12 +858,13 @@ classes = (
     FILEBROWSER_MT_view,
     FILEBROWSER_MT_select,
     FILEBROWSER_MT_context_menu,
+    FILEBROWSER_MT_view_pie,
     ASSETBROWSER_PT_display,
     ASSETBROWSER_PT_filter,
     ASSETBROWSER_MT_editor_menus,
     ASSETBROWSER_MT_view,
     ASSETBROWSER_MT_select,
-    ASSETBROWSER_MT_edit,
+    ASSETBROWSER_MT_catalog,
     ASSETBROWSER_MT_metadata_preview_menu,
     ASSETBROWSER_PT_metadata,
     ASSETBROWSER_PT_metadata_preview,
@@ -857,6 +873,7 @@ classes = (
     ASSETBROWSER_MT_context_menu,
 )
 
+
 def asset_path_str_get(_self):
     asset_file_handle = bpy.context.asset_file_handle
     if asset_file_handle is None:
@@ -865,8 +882,7 @@ def asset_path_str_get(_self):
     if asset_file_handle.local_id:
         return "Current File"
 
-    asset_library_ref = bpy.context.asset_library_ref
-    return bpy.types.AssetHandle.get_full_library_path(asset_file_handle, asset_library_ref)
+    return bpy.types.AssetHandle.get_full_library_path(asset_file_handle)
 
 
 def register_props():
